==> modx-2.1.5-pl-ja.zip: modx-2.1.5-pl-ja/core/lexicon/en/file.inc.php <==
<?php
/**
 * File English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['file_confirm_remove'] = 'Are you sure you want to remove this file? This could potentially break your website.';
$_lang['file_deleted'] = 'Success!';
$_lang['file_delete_file'] = 'Delete File';
$_lang['file_delete_folder'] = 'Delete Folder';
$_lang['file_download_file'] = 'Download File';
$_lang['file_download_unzip'] = 'Unzip File';
$_lang['file_edit'] = 'Edit File';
$_lang['file_err_chmod'] = 'An unknown error occurred while trying to chmod the target.';
$_lang['file_err_chmod_ns'] = 'Please specify a mode to chmod to.';
$_lang['file_err_ext_not_allowed'] = 'File extension `[[+ext]]` is not permitted.';
$_lang['file_err_filter'] = 'No files match the specified filter.';
$_lang['file_err_invalid'] = 'The file is not a regular file and cannot be removed.';
$_lang['file_err_nf'] = 'File does not exist!';
$_lang['file_err_ns'] = 'Please specify a valid file.';
$_lang['file_err_open'] = 'Cannot open file: ';
$_lang['file_err_perms_rename'] = 'The webserver does not have the necessary permissions to rename the file.';
$_lang['file_err_perms_remove'] = 'The webserver does not have the necessary permissions to remove the file.';
$_lang['file_err_rename'] = 'MODX failed to rename the file. Please make sure your permissions are set correctly.';
$_lang['file_err_remove'] = 'MODX failed to delete the file. Please make sure your permissions are set correctly.';
$_lang['file_err_save'] = 'Cannot save file, please ensure target directory is writable!';
$_lang['file_err_too_large'] = 'Uploaded file is too large at [[+size]] bytes. Please ensure your files are less than [[+allowed]] bytes.';
$_lang['file_err_unzip'] = 'Unzip Failed!';
$_lang['file_err_unzip_invalid_path'] = 'Invalid path for the unzipped file.';
$_lang['file_err_unzip_missing_lib'] = ' Missing zip library (php_zip.dll / zip.so)';
$_lang['file_err_upload'] = 'An error occurred while trying to upload the files.';
$_lang['file_exists_hk'] = 'File <b>{0}</b> already exists';
$_lang['file_extensions'] = 'File Extensions';
$_lang['file_folder_enter_new'] = 'Enter New Folder Name';
$_lang['file_folder_chmod'] = 'Chmod Directory';
$_lang['file_folder_create'] = 'Create Directory';
$_lang['file_folder_create_here'] = 'Create Directory Here';
$_lang['file_folder_created'] = 'Folder created successfully!';
$_lang['file_folder_deleted'] = 'Folder was successfully deleted!';
$_lang['file_folder_err_ae'] = 'A directory already exists with that name in that location.';
$_lang['file_folder_err_chmod'] = 'Unable to change permissions, you will need to change permissions outside of MODX.';
$_lang['file_folder_err_create'] = 'An unknown error occurred while trying to create the directory.';
$_lang['file_folder_err_invalid'] = 'The specified directory is not a directory.';
$_lang['file_folder_err_invalid_path'] = 'Invalid path to create the new folder in.';
$_lang['file_folder_err_nf'] = 'Folder does not exist!';
$_lang['file_folder_err_ns'] = 'Please specify a valid directory.';
$_lang['file_folder_err_ns_name'] = 'Please specify a valid name for the folder.';
$_lang['file_folder_err_parent_invalid'] = 'Specified parent directory is not a directory.';
$_lang['file_folder_err_perms'] = 'The webserver does not have the necessary permissions to update the directory.';
$_lang['file_folder_err_perms_parent'] = 'The webserver does not have the necessary permissions to add a directory there.';
$_lang['file_folder_err_perms_remove'] = 'The webserver does not have the necessary permissions to remove the directory.';
$_lang['file_folder_err_perms_upload'] = 'The webserver does not have the necessary permissions to upload to the directory.';
$_lang['file_folder_err_rename'] = 'An unknown error occurred while trying to rename the directory.';
$_lang['file_folder_err_remove'] = 'An error occurred while trying to remove the directory.';
$_lang['file_folder_parent'] = 'Parent Directory';
$_lang['file_folder_remove'] = 'Remove Directory';
$_lang['file_folder_remove_confirm'] = 'Are you sure you want to remove this directory? This could potentially break your website.';
$_lang['file_last_accessed'] = 'Last Accessed';
$_lang['file_last_modified'] = 'Last Modified';
$_lang['file_name'] = 'File Name';
$_lang['file_remove'] = 'Remove File';
$_lang['file_remove_confirm'] = 'Are you sure you want to remove this file entirely?';
$_lang['file_saved'] = 'File updated successfully!';
$_lang['file_size'] = 'File Size';
$_lang['file_unzip'] = 'Unzip was successful!';
$_lang['file_upload'] = 'Upload Files';
$_lang['file_upload_here'] = 'Upload Files Here';
$_lang['file_view'] = 'View File';
$_lang['files_access_denied'] = 'Access denied!';
$_lang['files_data'] = 'Data';
$_lang['files_directories'] = 'Directories';
$_lang['files_dirwritable'] = 'Directory writable?';
$_lang['files_dir_listing'] = 'Directory listing for:';
$_lang['files_editfile'] = 'Edit file';
$_lang['files_filename'] = 'Filename';
$_lang['files_fileoptions'] = 'Options';
$_lang['files_files'] = 'Files';
$_lang['files_filesize'] = 'File size';
$_lang['files_file_type'] = 'File type: ';
$_lang['files_modified'] = 'Modified';
$_lang['files_viewfile'] = 'View file';
$_lang['upf_abort'] = 'Abort';
$_lang['upf_abort_desc'] = 'Stop the upload.';
$_lang['upf_aborted'] = 'Aborted by user.';
$_lang['upf_add'] = 'Add';
$_lang['upf_add_desc'] = 'Add file into upload queue.';
$_lang['upf_close'] = 'Close';
$_lang['upf_close_desc'] = 'Close the window.';
$_lang['upf_err_failed'] = 'Server is unavailable or internal server error occured.';
$_lang['upf_err_filetype'] = 'Selected file extension isn\'t permitted.<br/>Please select files with following extensions: {1}';
$_lang['upf_error'] = 'Error';
$_lang['upf_filename'] = 'Filename';
$_lang['upf_note'] = 'Note';
$_lang['upf_progress_wait'] = 'Waiting...';
$_lang['upf_queued'] = 'Queued for upload.';
$_lang['upf_remove'] = 'Remove';
$_lang['upf_remove_desc'] = 'Remove file from upload queue.';
$_lang['upf_reset'] = 'Reset';
$_lang['upf_reset_desc'] = 'Reset queue.';
$_lang['upf_state'] = 'State';
$_lang['upf_success'] = 'OK.';
$_lang['upf_upload'] = 'Upload';
$_lang['upf_upload_desc'] = 'Upload queued files to the server.';
$_lang['upf_upload_err'] = 'Upload error.';
$_lang['upf_uploading'] = 'Uploading...';
$_lang['upf_uploading_desc'] = 'Uploading: {0} of {1} files complete.';
$_lang['upload_files'] = 'Upload Files';

==> modx-2.3.3-pl-ja.zip: modx-2.3.3-pl-ja/core/lexicon/en/file.inc.php <==
<?php
/**
 * File English lexicon topic
 *
 * @language en
 * @package modx
 * @subpackage lexicon
 */
$_lang['directory'] = 'Directory';
$_lang['file_confirm_remove'] = 'Are you sure you want to remove this file? Removing a file could potentially break your website. Make sure you know what this file does before removing it.';
$_lang['file_create'] = 'Create File';
$_lang['file_deleted'] = 'Success!';
$_lang['file_delete_file'] = 'Delete File';
$_lang['file_delete_folder'] = 'Delete Folder';
$_lang['file_download'] = 'Download File';
$_lang['file_download_file'] = 'Download File';
$_lang['file_download_unzip'] = 'Unzip File';
$_lang['file_edit'] = 'Edit File';
$_lang['file_err_ae'] = 'File %s already exists';
$_lang['file_err_chmod'] = 'An unknown error occurred while trying to chmod the target.';
$_lang['file_err_chmod_ns'] = 'Please specify a mode to chmod to.';
$_lang['file_err_create'] = 'An unknown error occurred while trying to create the file.';
$_lang['file_err_ext_not_allowed'] = 'File extension `[[+ext]]` is not permitted.';
$_lang['file_err_filter'] = 'No files match the specified filter.';
$_lang['file_err_invalid'] = 'The file is not a regular file and cannot be removed.';
$_lang['file_err_nf'] = 'File does not exist!';
$_lang['file_err_ns'] = 'Please specify a valid file.';
$_lang['file_err_open'] = 'Cannot open file: ';
$_lang['file_err_perms_rename'] = 'The webserver does not have the necessary permissions to rename the file.';
$_lang['file_err_perms_remove'] = 'The webserver does not have the necessary permissions to remove the file.';
$_lang['file_err_rename'] = 'MODX failed to rename the file. Please make sure your permissions are set correctly.';
$_lang['file_err_remove'] = 'MODX failed to delete the file. Please make sure your permissions are set correctly.';
$_lang['file_err_save'] = 'Cannot save file, please ensure target directory is writable!';
$_lang['file_err_too_large'] = 'Uploaded file is too large at [[+size]] bytes. Please ensure your files are less than [[+allowed]] bytes.';
$_lang['file_err_unzip'] = 'Unzip Failed!';
$_lang['file_err_unzip_invalid_path'] = 'Invalid path for the unzipped file.';
$_lang['file_err_unzip_missing_lib'] = 'Missing zip library (php_zip.dll / zip.so)';
$_lang['file_err_upload'] = 'An error occurred while trying to upload the files.';
$_lang['file_exists_hk'] = 'File <b>{0}</b> already exists';
$_lang['file_extensions'] = 'File Extensions';
$_lang['file_folder_enter_new'] = 'Enter New Folder Name';
$_lang['file_folder_chmod'] = 'Chmod Directory';
$_lang['file_folder_create'] = 'Create Directory';
$_lang['file_folder_create_here'] = 'Create Directory Here';
$_lang['file_folder_created'] = 'Folder created successfully!';
$_lang['file_folder_deleted'] = 'Folder was successfully deleted!';
$_lang['file_folder_err_ae'] = 'A directory already exists with that name in that location.';
$_lang['file_folder_err_chmod'] = 'Unable to change permissions, you will need to change permissions outside of MODX.';
$_lang['file_folder_err_create'] = 'An unknown error occurred while trying to create the directory.';
$_lang['file_folder_err_invalid'] = 'The specified directory is not a directory.';
$_lang['file_folder_err_invalid_path'] = 'Invalid path to create the new folder in.';
$_lang['file_folder_err_nf'] = 'Folder does not exist!';
$_lang['file_folder_err_ns'] = 'Please specify a valid directory.';
$_lang['file_folder_err_ns_name'] = 'Please specify a valid name for the directory.';
$_lang['file_folder_err_parent_invalid'] = 'Specified parent directory is not a directory.';
$_lang['file_folder_err_perms'] = 'The webserver does not have the necessary permissions to update the directory.';
$_lang['file_folder_err_perms_parent'] = 'The webserver does not have the necessary permissions to add a directory there.';
$_lang['file_folder_err_perms_remove'] = 'The webserver does not have the necessary permissions to remove the directory.';
$_lang['file_folder_err_perms_upload'] = 'The webserver does not have the necessary permissions to upload to the directory.';
$_lang['file_folder_err_rename'] = 'An unknown error occurred while trying to rename the directory.';
$_lang['file_folder_err_remove'] = 'An error occurred while trying to remove the directory.';
$_lang['file_folder_parent'] = 'Parent Directory';
$_lang['file_folder_remove'] = 'Delete Directory';
$_lang['file_folder_remove_confirm'] = 'Are you sure you want to remove this directory? This could potentially break your website.';
$_lang['file_last_accessed'] = 'Last Accessed';
$_lang['file_last_modified'] = 'Last Modified';
$_lang['file_name'] = 'File Name';
$_lang['file_quick_create'] = 'Quick Create File';
$_lang['file_quick_update'] = 'Quick Update File';
$_lang['file_remove'] = 'Delete File';
$_lang['file_remove_confirm'] = 'Are you sure you want to remove this file entirely?';
$_lang['file_saved'] = 'File updated successfully!';
$_lang['file_size'] = 'File Size';
$_lang['image_size'] = 'Image Size';
$_lang['file_unzip'] = 'Unzip was successful!';
$_lang['file_upload'] = 'Upload Files';
$_lang['file_upload_here'] = 'Upload Files Here';
$_lang['file_view'] = 'View File';
$_lang['files_access_denied'] = 'Access denied!';
$_lang['files_data'] = 'Data';
$_lang['files_directories'] = 'Directories';
$_lang['files_dirwritable'] = 'Directory writable?';
$_lang['files_dir_listing'] = 'Directory listing for:';
$_lang['files_editfile'] = 'Edit file';
$_lang['files_filename'] = 'Filename';
$_lang['files_fileoptions'] = 'Options';
$_lang['files_files'] = 'Files';
$_lang['files_filesize'] = 'File size';
$_lang['files_file_type'] = 'File type: ';
$_lang['files_modified'] = 'Modified';
$_lang['files_viewfile'] = 'View file';
$_lang['files_viewmode'] = 'View';
$_lang['files_viewmode_grid'] = 'Grid';
$_lang['files_viewmode_list'] = 'List';
$_lang['upf_abort'] = 'Abort';
$_lang['upf_abort_desc'] = 'Stop the upload.';
$_lang['upf_aborted'] = 'Aborted by user.';
$_lang['upf_add'] = 'Add';
$_lang['upf_add_desc'] = 'Add file into upload queue.';
$_lang['upf_close'] = 'Close';
$_lang['upf_close_desc'] = 'Close the window.';
$_lang['upf_err_failed'] = 'Server is unavailable or internal server error occured.';
$_lang['upf_err_filetype'] = 'Selected file extension isn\'t permitted.<br/>Please select files with following extensions: {1}';
$_lang['upf_error'] = 'Error';
$_lang['upf_filename'] = 'Filename';
$_lang['upf_note'] = 'Note';
$_lang['upf_progress_wait'] = 'Waiting...';
$_lang['upf_queued'] = 'Queued for upload.';
$_lang['upf_remove'] = 'Delete';
$_lang['upf_remove_desc'] = 'Delete file from upload queue.';
$_lang['upf_reset'] = 'Reset';
$_lang['upf_reset_desc'] = 'Reset queue.';
$_lang['upf_state'] = 'State';
$_lang['upf_success'] = 'OK.';
$_lang['upf_upload'] = 'Upload';
$_lang['upf_upload_desc'] = 'Upload queued files to the server.';
$_lang['upf_upload_err'] = 'Upload error.';
$_lang['upf_uploading'] = 'Uploading...';
$_lang['upf_uploading_desc'] = 'Uploading: {0} of {1} files complete.';
$_lang['upload_files'] = 'Upload Files';
$_lang['no_file_err'] = 'No file was uploaded.';

$_lang['upload.buttons.choose']           = 'Choose file(s)';
$_lang['upload.buttons.clear']            = 'Empty list';
$_lang['upload.buttons.upload']           = 'Upload';
$_lang['upload.buttons.close']            = 'Close';
$_lang['upload.title.destination_path']   = 'Upload destination: [[+path]]';
$_lang['upload.upload_progress']          = '[[+loaded]] / [[+total]]';
$_lang['upload.notpermitted.extension']   = 'Upload of this filetype (.[[+ext]]) is not allowed!';
$_lang['upload.notpermitted.filesize']    = 'Filesize bigger ([[+size]]) than allowed! (max. [[+max]])';
$_lang['upload.columns.file']             = 'File';
$_lang['upload.columns.state']            = 'State';
$_lang['upload.contextmenu.remove_entry'] = 'Remove entry';
$_lang['upload.clear_list.all']           = 'Clear list';
$_lang['upload.clear_list.notpermitted']  = 'Remove not permitted only';
$_lang['upload.msg.title.error']          = 'Error';
$_lang['upload.upload.success']           = 'Upload successful';
